@@ -321,8 +321,8 @@ class TgWrap():
         return stop_processing
 
     def _run_di_graph(
-        self, command, exclude_external_dependencies, start_at_step, dry_run, parallel_execution,
-        ask_for_confirmation=False, collect_output_file=None,
+        self, command, exclude_external_dependencies, start_at_step, dry_run,
+        parallel_execution=False, ask_for_confirmation=False, collect_output_file=None,
         working_dir=None,
         ):
         "Runs the desired command in the directories as defined in the directed graph"
@@ -937,7 +937,7 @@ class TgWrap():
                     include_lock_file=True,
                     auto_approve=True,
                     dry_run=dry_run,
-                    clean_up=True,
+                    clean_up=False,
                 )
 
             if not dry_run:
@@ -947,6 +947,12 @@ locals {{
     version_tag="{version_tag}"
 }}
 """)
+        except KeyError as e:
+            self.printer.error(f'Error interpreting the manifest file. Please ensure it uses the proper format. Could not find element: {e}')
+            sys.exit(1)
+        except Exception as e:
+            self.printer.error(f'Unexpected error: {e}')
+            sys.exit(1)
         finally:
             try:
                 shutil.rmtree(temp_dir)
